@@ -1,22 +1,9 @@
-use super::super::app::{
-  configmaps::KubeConfigMap,
-  contexts,
-  deployments::KubeDeployment,
-  metrics::{self, KubeNodeMetrics},
-  models::KubeResource,
-  nodes::KubeNode,
-  ns::KubeNs,
-  pods::KubePod,
-  replicasets::KubeReplicaSet,
-  statefulsets::KubeStatefulSet,
-  svcs::KubeSvc,
-};
-use super::Network;
+use std::fmt;
 
 use anyhow::anyhow;
 use k8s_openapi::api::core::v1::{Namespace, Node, Pod};
 use kube::{
-  api::{ListMeta, ListParams, ObjectList, Request},
+  api::{ListMeta, ListParams, ObjectList},
   config::Kubeconfig,
   Api, Resource as ApiResource,
 };
@@ -25,7 +12,25 @@ use kubectl_view_allocations::{
   extract_utilizations_from_pod_metrics, make_qualifiers, metrics::PodMetrics, Resource,
 };
 use serde::de::DeserializeOwned;
-use std::fmt;
+
+use super::Network;
+use crate::app::{
+  configmaps::KubeConfigMap,
+  contexts,
+  cronjobs::KubeCronJob,
+  daemonsets::KubeDaemonSet,
+  deployments::KubeDeployment,
+  jobs::KubeJob,
+  metrics::{self, KubeNodeMetrics},
+  models::KubeResource,
+  nodes::KubeNode,
+  ns::KubeNs,
+  pods::KubePod,
+  replicasets::KubeReplicaSet,
+  secrets::KubeSecret,
+  statefulsets::KubeStatefulSet,
+  svcs::KubeSvc,
+};
 
 impl<'a> Network<'a> {
   pub async fn get_kube_config(&self) {
@@ -108,13 +113,11 @@ impl<'a> Network<'a> {
       }
     }
 
-    // custom request since metrics API doesnt exist on kube-rs
-    let request = Request::new("/apis/metrics.k8s.io/v1beta1/pods");
-    match self
-      .client
-      .clone()
-      .request::<ObjectList<PodMetrics>>(request.list(&ListParams::default()).unwrap())
-      .await
+    let api_pod_metrics: Api<PodMetrics> = Api::all(self.client.clone());
+
+    match api_pod_metrics
+    .list(&ListParams::default())
+    .await
     {
       Ok(pod_metrics) => {
         if let Err(e) = extract_utilizations_from_pod_metrics(pod_metrics, &mut resources).await {
@@ -243,6 +246,33 @@ impl<'a> Network<'a> {
     app.data.replica_sets.set_items(items);
   }
 
+  pub async fn get_jobs(&self) {
+    let items: Vec<KubeJob> = self
+      .get_namespaced_resources(|it| KubeJob::from_api(it))
+      .await;
+
+    let mut app = self.app.lock().await;
+    app.data.jobs.set_items(items);
+  }
+
+  pub async fn get_cron_jobs(&self) {
+    let items: Vec<KubeCronJob> = self
+      .get_namespaced_resources(|it| KubeCronJob::from_api(it))
+      .await;
+
+    let mut app = self.app.lock().await;
+    app.data.cronjobs.set_items(items);
+  }
+
+  pub async fn get_secrets(&self) {
+    let items: Vec<KubeSecret> = self
+      .get_namespaced_resources(|it| KubeSecret::from_api(it))
+      .await;
+
+    let mut app = self.app.lock().await;
+    app.data.secrets.set_items(items);
+  }
+
   pub async fn get_deployments(&self) {
     let items: Vec<KubeDeployment> = self
       .get_namespaced_resources(|it| KubeDeployment::from_api(it))
@@ -252,6 +282,15 @@ impl<'a> Network<'a> {
     app.data.deployments.set_items(items);
   }
 
+  pub async fn get_daemon_sets_jobs(&self) {
+    let items: Vec<KubeDaemonSet> = self
+      .get_namespaced_resources(|it| KubeDaemonSet::from_api(it))
+      .await;
+
+    let mut app = self.app.lock().await;
+    app.data.daemon_sets.set_items(items);
+  }
+
   /// calls the kubernetes API to list the given resource for either selected namespace or all namespaces
   async fn get_namespaced_resources<K: ApiResource, T, F>(&self, map_fn: F) -> Vec<T>
   where
@@ -265,7 +304,11 @@ impl<'a> Network<'a> {
       Ok(list) => list.iter().map(map_fn).collect::<Vec<_>>(),
       Err(e) => {
         self
-          .handle_error(anyhow!("Failed to get resource. {:?}", e))
+          .handle_error(anyhow!(
+            "Failed to get resource {}. {:?}",
+            std::any::type_name::<T>(),
+            e
+          ))
           .await;
         vec![]
       }
